==> colorscheme-0.2.2.tar.bz2: colorscheme-0.2.2/src/dialogs/gcs-about-window.cc <==
/*******************************************************************************
 *  PROJECT: GNOME Colorscheme
 *
 *  AUTHOR: Jonathon Jongsma
 *
 *  Copyright (c) 2005 Jonathon Jongsma
 *
 *  License:
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the 
 *    Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
 *    Boston, MA  02111-1307  USA
 *
 *******************************************************************************/

#include <config.h>
#include <libgnome/gnome-url.h>

#include "gcs-about-window.h"
#include "../gcs-debug.h"
#include "../gcs-i18n.h"

namespace gcs
{
    namespace Dialogs
    {
        AboutWindow::AboutWindow(void)
        {
            set_name(PACKAGE_NAME);

            set_url_hook(sigc::mem_fun(*this, &AboutWindow::on_link_clicked));
            set_website(PACKAGE_BUGREPORT);
            set_website_label(_("Project Website"));

            Glib::ustring version(PACKAGE_VERSION);
            set_version(version);

            set_copyright("\xC2\xA9 2005 Jonathon Jongsma");

            Glib::ustring comments(
                    _("A program for the GNOME desktop for generating colorschemes"));
            if (SVN_REVISION != "exported")
            {
                comments.append("\n(Build " SVN_REVISION ")");
            }
            set_comments(comments);

            Glib::ustring license = "This program is free software; you can redistribute it and/or modify\n"
                "it under the terms of the GNU General Public License as published by\n"
                "the Free Software Foundation; either version 2 of the License, or\n"
                "(at your option) any later version.\n\n"

                "This program is distributed in the hope that it will be useful,\n"
                "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
                "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
                "GNU General Public License for more details.\n\n"

                "You should have received a copy of the GNU General Public License\n"
                "along with this program; if not, write to the \n"
                "Free Software Foundation, Inc., 59 Temple Place, Suite 330, \n"
                "Boston, MA  02111-1307  USA\n";
            set_license(license);

            m_authors.push_back("Jonathon Jongsma <jonathon.jongsma@gmail.com>");
            set_authors(m_authors);

            // Translators: change this to your name, separate multiple names with \n
            Glib::ustring translation_credits = _("translation-credits");

            // Only display a translator credit if the string has been translated
            if (translation_credits != "translation-credits")
            {
                set_translator_credits(translation_credits);
            }

            try
            {
                char *logo_file = COLORSCHEME_ICONDIR "/colorscheme-logo.png";
                debug("Logo: ", logo_file);
                m_logo = Gdk::Pixbuf::create_from_file(logo_file);
                set_logo(m_logo);

                char *icon_file = COLORSCHEME_ICONDIR "/colorscheme-icon.png";
                debug("Icon: ", icon_file);
                set_icon_from_file(icon_file);
            }
            catch(Glib::Error)
            {
                g_warning("Logo Image not found");
            }
        }


        void AboutWindow::on_link_clicked(Gtk::AboutDialog& dialog,
                const Glib::ustring& link)
        {
            gnome_url_show(link.c_str(), 0);
        }

    } // namespace Dialogs
} // namespace gcs

==> colorscheme-0.3.1.tar.bz2: colorscheme-0.3.1/src/dialogs/gcs-about-window.cc <==
/*******************************************************************************
 *  PROJECT: GNOME Colorscheme
 *
 *  AUTHOR: Jonathon Jongsma
 *
 *  Copyright (c) 2005 Jonathon Jongsma
 *
 *  License:
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the 
 *    Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
 *    Boston, MA  02111-1307  USA
 *
 *******************************************************************************/

#include <config.h>
#include <libgnome/gnome-url.h>

#include "gcs-about-window.h"
#include "../gcs-debug.h"
#include "../gcs-i18n.h"

namespace gcs
{
    namespace Dialogs
    {
        AboutWindow::AboutWindow(void)
        {
            set_name(PACKAGE_NAME);

            set_url_hook(sigc::mem_fun(*this, &AboutWindow::on_link_clicked));
            set_website(PACKAGE_WEBSITE);
            set_website_label(_("Project Website"));

            Glib::ustring version(PACKAGE_VERSION);
            set_version(version);

            set_copyright("\xC2\xA9 2005 Jonathon Jongsma");

            Glib::ustring comments(
                    _("A program for the GNOME desktop for generating colorschemes"));
            if (SVN_REVISION != "exported")
            {
                comments.append("\n(Build " SVN_REVISION ")");
            }
            set_comments(comments);

            Glib::ustring license = "This program is free software; you can redistribute it and/or modify\n"
                "it under the terms of the GNU General Public License as published by\n"
                "the Free Software Foundation; either version 2 of the License, or\n"
                "(at your option) any later version.\n\n"

                "This program is distributed in the hope that it will be useful,\n"
                "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
                "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
                "GNU General Public License for more details.\n\n"

                "You should have received a copy of the GNU General Public License\n"
                "along with this program; if not, write to the \n"
                "Free Software Foundation, Inc., 59 Temple Place, Suite 330, \n"
                "Boston, MA  02111-1307  USA\n";
            set_license(license);

            m_authors.push_back("Jonathon Jongsma <jonathon.jongsma@gmail.com>");
            set_authors(m_authors);

            // Translators: change this to your name, separate multiple names with \n
            Glib::ustring translation_credits = _("translation-credits");

            // Only display a translator credit if the string has been translated
            if (translation_credits != "translation-credits")
            {
                set_translator_credits(translation_credits);
            }

            try
            {
                char *logo_file = COLORSCHEME_ICONDIR "/colorscheme-logo.png";
                debug("Logo: ", logo_file);
                m_logo = Gdk::Pixbuf::create_from_file(logo_file);
                set_logo(m_logo);

                char *icon_file = COLORSCHEME_ICONDIR "/colorscheme-icon.png";
                debug("Icon: ", icon_file);
                set_icon_from_file(icon_file);
            }
            catch(Glib::Error)
            {
                g_warning("Logo Image not found");
            }
        }


        void AboutWindow::on_link_clicked(Gtk::AboutDialog& dialog,
                const Glib::ustring& link)
        {
            gnome_url_show(link.c_str(), 0);
        }

    } // namespace Dialogs
} // namespace gcs
